clear all
close all
clc

%% FOR THE PAPER 5 DIFFERENT SETTINGS HAVE BEEN USED
% 1) standard: chi = 8;   sigma = 0.05; block-wave; disc = 4; misspow = 0.3;
% 2) standard: chi = 100; sigma = 0.05; block-wave; disc = 4; misspow = 0;
% 3) standard: chi = 8;   sigma = 0.55; block-wave; disc = 4; misspow = 0;
% 4) standard: chi = 100; sigma = 0.05; sin-wave;   disc = 4; misspow = 0;
% 5) standard: chi = 8;   sigma = 0.05; block-wave; disc = 4; misspow = 0;


%%
set(0,'defaultaxesfontsize',14);
set(0,'defaultlinelinewidth',1.5);


MW2keVs = 6.24e21/2.1e19; % nog toepassen beter om varierende ne te nemen
misspow = 0.0;
disc = 1; 
%% Intialize numerical solution
x_e = 2.2; 
Ptot = 4*0.7; sigma = 0.05; xdep = 0.2;
N = disc*500; rpd = 0:x_e/N:x_e; rp = 1;
Pdep = MW2keVs*Ptot/(sigma*sqrt(pi))*exp(-(rpd(1:end-1)-xdep).^2/sigma.^2);
Pdepmp = (1-misspow)*Pdep;

sigma_local = 0.25;
Pdep_local = Pdep;%MW2keVs*Ptot/(sigma_local*sqrt(pi))*exp(-(rpd(1:end-1)-xdep).^2/sigma_local.^2);

chi = 1+0*rpd%1/5*rpd.^2 + rpd + 1;
V = -10*1/(sigma_local*sqrt(pi))*exp(-(rpd(1:end)-0.7).^2/sigma_local.^2); 
tau = 0;

dr = x_e/N;
X = 0:dr:x_e;


% total power calculation
for i = length(Pdep):-1:1;  
    Pint(:,i) = dr*trapz(Pdep(:,1:i).'/MW2keVs).';
end
figure(78)
plot(rpd(1:end-1)/x_e,Pint,'k'); xlabel('\rho');ylabel('P_{tot} [MW/m^2]')
grid on; axis([rpd(1)/x_e,rpd(end)/x_e,0,1.1*max(Pint)])
%%

[sys,Rp,y0,profiles] = CLFDstatespace(chi,V,tau,rp,rpd,X,Pdepmp,x_e,N);
 
 
%% lsim
f0 = 25;
Periods = 100;
dt = 0.0001;
t = 0:dt:(Periods/f0-dt);

usquare = 0.5+1*square(2*pi*f0*t)/2;
usin = 1+sin(2*pi*f0*t)/2; sinsqu = trapz(usquare(1:41))/trapz(usin(1:41));
u = usquare;
%%
% uin = [u;zeros(size(u))];
treal = t;%/(2*pi*100);
uin = u;
T0 = y0*mean(u);%*[0;0];



[yout,tout] = lsim(sys, uin, treal,T0); 

[~,b,~,~] = ssdata(sys);
Porg = 1/(1-misspow)*b; % missing power

Porg = Pdep_local.'; % redistribution
U = (Porg*uin).';

figure(100)
plot(tout,yout(:,200))

%% Calculate derivatives
dTdr = diff(yout.',1).'/(Rp(2)-Rp(1));
dTdt = diff(yout,1)/(tout(2)-tout(1));


%%
oPl = length(0:dt:(1/f0-dt));
indPl = size(tout,1)-oPl-1+1:1:size(tout,1)-1;
indPl2x = size(tout,1)-2*oPl-1:1:size(tout,1);


location = 10:10:N-1;
Rpt = ones(size(dTdt,1),1)*Rp;
Rout = Rp(location);

dTdtone = dTdt(indPl,:);
dTdrone = dTdr(indPl,:);
Pout = U(indPl,:);
tliss = t(indPl);
        
for i = length(location):-1:1;
    for j = length(indPl):-1:1;
        q0 = dr*1/Rp(location(i))*trapz((Rpt(j,1:location(i)).*dTdtone(j,1:location(i))).').';
        qP = dr*1/Rp(location(i))*trapz((Rpt(j,1:location(i)).*Pout(j,1:location(i))).').';

        q = -(q0-qP);

        input(j,i) = -dTdrone(j,location(i))/x_e; %rho
        output(j,i) = q;
        outputP(j,i) = qP; outputq0(j,i) = -q0;
    end    
end
outputdTdt = dTdt(indPl,location);

%%
figure(101)
plot(input,output)


% for l = 1:size(input,2)
%       figure(100+l)
%     plot(input(indPl,l),output(indPl,l))
%     axis([0,0.8,0,5])
% end

%%

%% Calculate dq
for l = 1:size(input,2)
    dq(l) = max(diff(output(:,l)));
    dqP(l) = max(diff(outputP(:,l)));
    dq0(l) = max(diff(outputq0(:,l)));
%     singnn = sign(diff(outputq0(:,l)));
%     dq0sign(l) = singnn(1).*max(diff(outputq0(:,l)));
end
% indPl = indPl -100;
% hf_t = output(indPl,:);
% 
% dTedravg = (max(input(indPl,:),[],1)+min(input(indPl,:),[],1))/2;
% zerocrossdet = input(indPl,:)-ones(size(input(indPl,:),1),1)*dTedravg;
% [kout,kerror] = zerocrossfind2(zerocrossdet);
% kdTdr1 = kout(1,:); kdTdr2 = kout(2,:);
% 
% dqdne   = abs(diag(hf_t(kdTdr1,:)-hf_t(kdTdr2,:)));


%% Plots %%%

set(0,'defaultaxesfontsize',12);
set(0,'defaultlinelinewidth',1.5);
indR = disc*5:disc*75:N;
indR = indR((1:end));

for i = 1:length(Rp(indR))
       Cell1{i} = sprintf('$$\\rho = %.2f$$',Rp(indR(i))/x_e);    
end

h1 = figure(1);
plot(tout(indPl2x),yout(indPl2x,indR))
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
xlabel('time [s]','interpreter','latex')
ylabel('$\tilde{T}_{e}$ [keV]','interpreter','latex')
axis('tight')
grid on
legend(Cell1,'interpreter','latex','location','NorthEast')
tightfig(h1);
annotation(h1,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(a)'},'LineStyle','none','FontSize',14,'interpreter','latex');
    
h2 = figure(2);
plot(tout(indPl),dTdt(indPl,indR))
xlabel('time [s]','interpreter','latex')
ylabel('$\partial\tilde{T}_{e}/\partial t$ [keV/s]','interpreter','latex')
grid on
axis('tight')
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
grid on
legend(Cell1(3:end),'interpreter','latex','location','NorthEast')
tightfig(h2);
annotation(h2,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(b)'},'LineStyle','none','FontSize',14,'interpreter','latex');


h3 = figure(3);
plot(tout(indPl),dTdr(indPl,indR)*x_e)
legend(Cell1,'interpreter','latex','location','NorthEast')
xlabel('time [s]','interpreter','latex')
ylabel('$\partial\tilde{T}_{e}/\partial \rho$ [keV]','interpreter','latex')
grid on
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
tightfig(h3);
annotation(h3,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(c)'},'LineStyle','none','FontSize',14,'interpreter','latex');


%% Calculate Lissajous
loc30 = 20*disc;
loc = loc30;

%%
loc = loc30;
step = round(2e-3/mean(diff(tout)));


ilp = 1:1:length(input);
indPls = ilp(1:step:end);
dtous = tout(step+1)-tout(1);
labels = cellstr(num2str([1:1:length(indPls)]') );  %' # labels correspond to their order


h5 = figure(5);
hold on
plot(input(ilp,loc)*x_e,output(ilp,loc),'-','color',[27 158 119]/255)
plot(input(indPls,loc)*x_e,output(indPls,loc),'k.','markersize',20)
hold off
box on
text(input(indPls(1:2:end),loc)*x_e,output(indPls(1:2:end),loc), labels(1:2:end), 'VerticalAlignment','bottom','HorizontalAlignment','right')
text(input(indPls(2:2:end),loc)*x_e,output(indPls(2:2:end),loc), labels(2:2:end), 'VerticalAlignment','top','HorizontalAlignment','left')  

% legend('block-wave','sine-wave',4)
% axis([-1.2,1.2,-1.2,1.2])
grid on
xlabel('-\nabla_{\rho}T_{e} [keV]')
ylabel('\deltaq_e/n_e [keVm/s]')
legend('Lissajous',sprintf('\\Deltat = %.f [ms]',dtous*1e3),'Location','NorthWest'); 
title(sprintf('\\rho = %.1f',Rout(loc)/x_e))
axis([0.70*min(input(ilp,loc)*x_e),1.05*max(input(ilp,loc)*x_e),-3,1.1*max(outputP(ilp,loc))])

rico =   (output(end-oPl+20)-output(end-oPl))...
         /(input(end-oPl+20)-input(end-oPl)); 

 
tightfig(h5)

annotation(h5,'doublearrow',[0.519529072964739 0.519529072964739],[0.597218851279223 0.399485557315982],'Color',[0.501960784313725 0.501960784313725 0.501960784313725]);
annotation(h5,'textbox',[0.520199402947755 0.461961062150783 0.154285717538425 0.0980952398663476],...
    'String',{'\Deltaq_e/n_e'},'LineStyle','none','FontSize',14,'Color',[0.501960784313725 0.501960784313725 0.501960784313725]);     
     

%% 
     
     
%% additional figures
% figure(7)
% plot(Rp(1:end),dTdr(1:100:end,:))
% xlabel('r [m]')
% ylabel('dT/dr')
% grid on
rholoc = Rp(location)/x_e;
irl = 1:10:length(rholoc);

h7 = figure(7);
hold on
plot(rholoc,dq0,'r-')
plot(rholoc,dqP,'b-')
plot(rholoc,dq,'k-',rholoc(irl),dq(irl),'ko')
plot(rholoc(irl),dq0(irl),'rx')
% plot(rholoc(irl),dqP(irl),'bd','color',[27 158 119]/255)
hold off
box on
xlabel('$\rho$ [-]','interpreter','latex')
ylabel('$\Delta q_e/n_e$ [keVm/s]','interpreter','latex')
hl7 = legend('$\Delta q_{\partial T/\partial t}$','$\Delta q_{P}/n_e$','$\Delta q_{e}/n_e$'); set(hl7','interpreter','latex');
grid on
axis([0,1,0,1.1*max([dq0,dqP])])
tightfig(h7);
annotation(h7,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(b)'},'LineStyle','none','FontSize',14,'interpreter','latex');


sigma_local = 0.05;
Pdep_local = Ptot/(sigma_local*sqrt(pi))*exp(-(rpd(1:end-1)-xdep).^2/sigma_local.^2);

h8 = figure(8);
plot(rholoc,dq,'k-',rpd(1:end-1)/x_e,Pdep_local*5,'k--',...
    rpd(1:end-1)/x_e,misspow*Pdep_local*5,'k-.',rholoc(irl),dq(irl),'ko')
xlabel('\rho [-]')
ylabel('\Delta q_e/n_e [keVm/s], P_{ech} [0.2 MW/m^3]')
legend('\Deltaq_{e}/n_e','P_{ech}(\rho)','P_{mp}(\rho)')
grid on
tightfig(h8);
annotation(h8,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(c)'},'LineStyle','none','FontSize',14);


% axis([0,1,0,1.1*max([dq,dq])])
%% Normalized radius of all three
loc = loc30;

h35_3 = figure(353);
hold on
plot(input(ilp,loc)*x_e,output(ilp,loc),'k')
h3f_3p= plot(input(indPls,loc)*x_e,output(indPls,loc),'k.','markersize',20)
hold off; box on;
text(input(indPls(1:2:end),loc)*x_e,output(indPls(1:2:end),loc), labels(1:2:end), 'VerticalAlignment','bottom','HorizontalAlignment','right','interpreter','latex')
text(input(indPls(2:2:end),loc)*x_e,output(indPls(2:2:end),loc), labels(2:2:end), 'VerticalAlignment','top','HorizontalAlignment','left','interpreter','latex')  

% legend('block-wave','sine-wave',4)
axis([0.99*min(input(ilp,loc)*x_e),1.01*max(input(ilp,loc)*x_e),0.97*min(output(ilp,loc)),1.05*max(output(ilp,loc))])
grid on
xlabel('$-\nabla_{\rho}\tilde{T}_{e}$ [keV]','interpreter','latex')
ylabel('$\tilde{q}_e/n_e$ [keVm/s]','interpreter','latex')
legend([h3f_3p],{sprintf('$$\\Delta t = %.f$$ [ms]',dtous*1e3)},'Location','NorthWest','interpreter','latex'); 
ht35t = title(sprintf('$$\\rho = %.1f$$',Rout(loc)/x_e)); set(ht35t,'interpreter','latex')
tightfig(h35_3);
annotation(h35_3,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(b)'},'LineStyle','none','FontSize',14,'interpreter','latex');

annotation(h35_3,'doublearrow',[0.5011 0.5011],[0.583 0.372],'Color',[0.501960784313725 0.501960784313725 0.501960784313725]);
annotation(h35_3,'textbox',[0.514469633582642 0.452430559441117 0.154285717538424 0.0980952398663476],...
    'String',{'$\Delta q_e/n_e$'},'LineStyle','none','FontSize',14,'Color',[0.501960784313725 0.501960784313725 0.501960784313725],'interpreter','latex');   



% +++++++++++++++++++++++++++++++

h35_2 = figure(352);
hold on
plot(input(ilp,loc)*x_e,outputP(ilp,loc),'b')
plot(input(indPls,loc)*x_e,outputP(indPls,loc),'k.','markersize',20)
hold off; box on
text(input(indPls(1:2:end),loc)*x_e,outputP(indPls(1:2:end),loc), labels(1:2:end), 'VerticalAlignment','bottom','HorizontalAlignment','right','interpreter','latex')
text(input(indPls(2:2:end),loc)*x_e,outputP(indPls(2:2:end),loc), labels(2:2:end), 'VerticalAlignment','top','HorizontalAlignment','left','interpreter','latex')  


% legend('block-wave','sine-wave',4)
grid on
xlabel('$-\nabla_{\rho}\tilde{T}_{e}$ [keV]','interpreter','latex')
ylabel('$\tilde{q}_P/n_e$ [keVm/s]','interpreter','latex')
legend([h3f_3p],{sprintf('$$\\Delta t = %.f$$ [ms]',dtous*1e3)},'Location','NorthWest','interpreter','latex'); 
ht354t = title(sprintf('$$\\rho = %.1f$$',Rout(loc)/x_e)); set(ht354t,'interpreter','latex')
axis([0.99*min(input(ilp,loc)*x_e),1.02*max(input(ilp,loc)*x_e),-3,1.1*max(outputP(ilp,loc))])
tightfig(h35_2);

annotation(h35_2,'doublearrow',[0.52 0.52],[0.863298301529979 0.207065191697735],'Color',[0.501960784313725 0.501960784313725 0.501960784313725]);
annotation(h35_2,'textbox',[0.512430656266374 0.456176522573918 0.154285717538425 0.0980952398663476],...
    'String',{'$\Delta q_{P}/n_e$'},'LineStyle','none','FontSize',14,'interpreter','latex','Color',[0.501960784313725 0.501960784313725 0.501960784313725]);   
annotation(h35_2,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(a)'},'LineStyle','none','FontSize',14,'interpreter','latex');




% +++++++++++++++++++++++++++++++
h35_1 = figure(351);
hold on
plot(input(ilp,loc)*x_e,outputq0(ilp,loc),'r');
h35_1b = plot(input(indPls,loc)*x_e,outputq0(indPls,loc),'k.','markersize',20);
hold off; box on

text(input(indPls(1:2:end),loc)*x_e,outputq0(indPls(1:2:end),loc), labels(1:2:end), 'VerticalAlignment','bottom','HorizontalAlignment','right','interpreter','latex')
text(input(indPls(2:2:end),loc)*x_e,outputq0(indPls(2:2:end),loc), labels(2:2:end), 'VerticalAlignment','top','HorizontalAlignment','left','interpreter','latex')  

grid on
xlabel('$-\nabla_{\rho}\tilde{T}_{e}$ [keV]','interpreter','latex')
ylabel('$\tilde{q}_{\partial T/\partial t}/n_e$ [keVm/s]','interpreter','latex')
legend([h3f_3p],{sprintf('$$\\Delta t = %.f$$ [ms]',dtous*1e3)},'Location','NorthWest','interpreter','latex'); 
ht354t2 = title(sprintf('$$\\rho = %.1f$$',Rout(loc)/x_e)); set(ht354t2,'interpreter','latex')

axis([0.98*min(input(ilp,loc)*x_e),1.02*max(input(ilp,loc)*x_e),1.1*min(outputq0(ilp,loc)),1.1*max(outputq0(ilp,loc))])

tightfig(h35_1);

annotation(h35_1,'doublearrow',[0.538568412704327 0.535809018567639],[0.862393940032093 0.220257234726688],'Color',[0.501960784313725 0.501960784313725 0.501960784313725]);
annotation(h35_1,'textbox',[0.546170080526899 0.485160545795633 0.154285717538423 0.0980952398663479],...
    'String',{'$\Delta q_{\partial T/\partial t}$'},'LineStyle','none','FontSize',14,'interpreter','latex','Color',[0.501960784313725 0.501960784313725 0.501960784313725]); 
annotation(h35_1,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(b)'},'LineStyle','none','FontSize',14,'interpreter','latex');








return
%% All three
%

load('PdTdt.mat')

Rpp = (ones(1,1)*Rp(location)); dRpp = median(diff(Rpp));
PdTdt = 1/dRpp*1./Rpp(:,1:end-1).*diff(Rpp.*dq0,[],2);
Rpp_rec = Rpp(1:end-1)/x_e+0.5*dRpp/x_e; % shift half sample
h77 = figure(77);
hold on 
plot(Rp/x_e,Porg/MW2keVs,'b-')
plot(Rp/x_e,1/(1-misspow)*b/MW2keVs,'-','color',[27 158 119]/255)
plot(Rp/x_e,b/MW2keVs,'r')
plot(Rpp_rec(1:3:end),PdTdt_mponly(1:3:end)/MW2keVs,'k+')
plot(Rpp_rec(1:3:end),PdTdt(1:3:end)/MW2keVs,'kx')
hold off; box on    
xlabel('$\rho$ [-]','interpreter','latex');
ylabel('$P_{ech}\left(\rho\right)$, $P_{\mathit{eff}}\left(\rho\right)$ [MW/m$^3$]','interpreter','latex')
grid on
axis([0, 0.6, 0, 1])
hl77 = legend('$P_{ech}(\rho)$',...
       '$T_c: P_{\mathit{eff}}(\rho)$',...
       '$T_s: P_{\mathit{eff}}(\rho)$',...
       '$P_{\mathit{eff}}(\rho)$ constructed from $\partial T/\partial t (T_c)$',...
       '$P_{\mathit{eff}}(\rho)$ constructed from $\partial T/\partial t (T_s)$');
set(hl77,'interpreter','latex')

Rpp = (ones(1,1)*Rp(location)); dRpp = median(diff(Rpp));
PdTdt = 1/dRpp*1./Rpp(:,1:end-1).*diff(Rpp.*dq0,[],2);
tightfig(h77)
% annotation(h77,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(c)'},'LineStyle','none','FontSize',14,'interpreter','latex');
% 
% hl77 = legend('P$_{\textrm{ech}}$')
% % hl77 = legend('P_{eff}')
% set(hl77,'interpreter','latex')
% 

% figure(78)
% plot(Rp/x_e,b/MW2keVs,'r',Rpp(1:end-1)/x_e+0.5*dRpp/x_e,PdTdt/MW2keVs,'b')
% xlabel('\rho [-]');
% ylabel('P [MW/m^3]')
% grid on
% axis('tight')
% legend('P_{ech}(\rho)','P_{rd}(\rho)')



%%
% plot(Rpp(1:end-1)/x_e+0.022/x_e,PdTdt*6.7e3,Rp/x_e,b)

lochyst = disc*1:disc*7:size(input,2);

for i = 1:length(lochyst)
       CelldTdt{i} = sprintf('\\rho = %.2f',Rp(location(lochyst(i)))/x_e);    
end

figure(9)
plot(input(:,lochyst),outputdTdt(:,lochyst))
xlabel('-\nabla_{\rho}T [keV]')
ylabel('\partialT_e/\partial t [keV/s m^{-3}]')
grid on
legend(CelldTdt)


return
%% plot confinement time
outputdT = dTdt;

figure(345)
plot(input(ilp,loc)/x_e,outputdT(ilp,loc),'k',input(indPls,loc)/x_e,outputdT(indPls,loc),'k.','markersize',20)%,ysin,iout,'r')
text(input(indPls(1:2:end),loc)/x_e,outputdT(indPls(1:2:end),loc), labels(1:2:end), 'VerticalAlignment','bottom','HorizontalAlignment','right')
text(input(indPls(2:2:end),loc)/x_e,outputdT(indPls(2:2:end),loc), labels(2:2:end), 'VerticalAlignment','top','HorizontalAlignment','left')  

% legend('block-wave','sine-wave',4)
axis([0.9*min(input(ilp,loc)/x_e),1.1*max(input(ilp,loc)/x_e),1.1*min(outputdT(ilp,loc)),1.1*max(outputdT(ilp,loc))])
grid on
xlabel('-\nabla_{\rho}T [keV]')
ylabel('\deltaq_e [keV/s]')
legend('Lissajous',sprintf('\\Deltat = %.f [ms]',dtous*1e3),'Location','NorthWest'); 
title(sprintf('\\rho = %.3f',Rout(loc)/x_e))


%%
% [dTdrm,IdTdr] = max(dTdr(indPl,indR));
% 
% figure(5)
% subplot(2,1,1)
% plot(tout(indPl),log(yout(indPl,indR)))
% xlabel('time [s]')
% ylabel('T_{e} [keV]')
% axis('tight')
% grid on
% legend(Cell1,'Location','NorthWest')
% subplot(2,1,2)
% plot(tout(indPl),log(dTdr(indPl,indR)))
% xlabel('time [s]')
% ylabel('dT_{e}/dr [keV/m]')
% axis('tight')
% grid on
% legend(Cell1,'Location','NorthWest')
% 
% figure
% plot(Rp(indR),-max(dTdr(indPl,indR))+max(yout(indPl,indR)))
