clear all
close all
clc

%% Colors
c1 = [27 158 119]; c2 = [217 95 2]; c3 = [117 112 179]; 
c4 = [231 41 138]; c5 = [102 166 30]; c6 = [230 171 2];
c7 = [166 118 29]; c8 = [102 102 102];
colour = [c1;c2;c3;c4;c5;c6;c7;c8]/255; 

cp1 = [255,0,0]/255; cp2 = [0,0,255]/255; cp3 = c6; cp4 = c4; cp5 = c3; cp6 = [255,0,255]/255; cp7 = [0,255,255]/255; cp8 = [0,0,0];
cp9 = 2*[85,85,85]/255; cp10 = 0.75*[102 166 30]/255; cp11 = c1;%[85,85,85]/255;
cp12 = c2; cp13 = [255,153,153]/255;
cp = [cp1;cp2;cp3;cp4;cp5;cp6;cp7;cp8;cp9;cp10;cp11;cp12;cp13]/255;
figure(7777); hold on; for i=1:length(colour); plot([i,i+1],[i,i+1],'color',colour(i,:));end;
figure(7778); hold on; for i=1:length(cp); plot([i,i+1],[i,i+1],'color',cp(i,:));end; 
%%

%%
set(0,'defaultaxesfontsize',12);
set(0,'defaultlinelinewidth',1.5);

chi = 8; V = 0; tau = 0;

MW2keVs = 6.24e21/2.1e19; % nog toepassen beter om varierende ne te nemen

%% Intialize numerical solution
x_e = 2.2; 
Ptot = 0.7; sigma = 0.55; xdep = 0.2;
N = 2000; rpd = 0:x_e/N:x_e; rp = 1;

dr = x_e/N; X = 0:dr:x_e;
Rp = X(1:end-1);

f0 = 12.5; F = [1,2,6,10,40];
f = F*f0; omega = 2*pi*f;
for i = 1:length(F); Cell1{i} = sprintf('$f$ = %.f Hz',f(i)); end    
Cell1{1} = '$f$ = 12.5 Hz';

%% Fourier components source
dt = 1e-6; nn = 5;
t = 0:dt:nn/f0-dt;
usquare = 0.5+square(2*pi*f0*t)/2;
Usquare = 0.5*fft(usquare)/length(usquare);
Fp = F*nn+1; % uneven harmonic components
Pomega = Usquare(Fp);

figure(1); semilogy(1:100,abs(Usquare(1:100)),'b+',Fp,abs(Pomega),'ro')

%% Deposition profiles

sigma = 0.05; xdep = 0.2;
Pdep1 = MW2keVs*Ptot/(sigma*sqrt(pi))*exp(-(rpd(1:end-1)-xdep).^2/sigma.^2);

sigma = 0.55; xdep = 0.2;
Pdep2 = (1-0.3)*MW2keVs*Ptot/(sigma*sqrt(pi))*exp(-(rpd(1:end-1)-xdep).^2/sigma.^2);

%% Calculate harmonic components


[sys1,~,~,~] = SlabFDstatespace(chi,V,tau,rp,rpd,X,Pdep1,x_e,N);
[sys2,~,~,~] = SlabFDstatespace(chi,V,tau,rp,rpd,X,Pdep2,x_e,N);

% [sys1,~,~,~] = CLFDstatespace(chi,V,tau,rp,rpd,X,Pdep1,x_e,N);
% [sys2,~,~,~] = CLFDstatespace(chi,V,tau,rp,rpd,X,Pdep2,x_e,N);

[Ghnum1] = Calculate_harmonic_components_mini(sys1,omega);
[Ghnum2] = Calculate_harmonic_components_mini(sys2,omega);

Theta1 = Ghnum1%.*(Pomega.'*ones(size(X)));
Theta2 = Ghnum2;%.*(Pomega.'*ones(size(X)));
%%


h78 = figure(78);
hold on
semilogy(Rp/x_e,abs(Theta1(1,1:end-1)),'color',colour(4,:))
semilogy(Rp/x_e,abs(Theta1(2,1:end-1)),'color',colour(6,:))
semilogy(Rp/x_e,abs(Theta1(3,1:end-1)),'color',colour(5,:))
semilogy(Rp/x_e,abs(Theta1(4,1:end-1)),'color',colour(8,:))
semilogy(Rp/x_e,abs(Theta1(5,1:end-1)),'color',colour(2,:))
% semilogy(Rp/x_e,abs(Theta1(6,1:end-1)),'color',colour(3,:))

semilogy(Rp/x_e,abs(Theta2(1,1:end-1)),'--','color',colour(4,:))
semilogy(Rp/x_e,abs(Theta2(2,1:end-1)),'--','color',colour(6,:))
semilogy(Rp/x_e,abs(Theta2(3,1:end-1)),'--','color',colour(5,:))
semilogy(Rp/x_e,abs(Theta2(4,1:end-1)),'--','color',colour(8,:))
semilogy(Rp/x_e,abs(Theta2(5,1:end-1)),'--','color',colour(2,:))
% semilogy(Rp/x_e,abs(Theta2(6,1:end-1)),'--','color',colour(3,:))
hold off
set(gca,'yscale','log')
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
box on; grid on; xlabel('$\rho$ [-]','interpreter','latex');ylabel('$\left|\tilde{T}_e\right|$ [keV]','interpreter','latex')
axis([0,1,1e-5,max(abs(Theta1(1,1:end-1)))])
l1 = legend(Cell1,'location','SouthWest'); set(l1,'interpreter','latex');
annotation(h78,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(a)'},'LineStyle','none','FontSize',14,'interpreter','latex');

% 
tightfig(h78)

h79 = figure(79);
hold on
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta1(1,1:end-1))),'color',colour(4,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta1(2,1:end-1))),'color',colour(6,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta1(3,1:end-1))),'color',colour(5,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta1(4,1:end-1))),'color',colour(8,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta1(5,1:end-1))),'color',colour(2,:))

semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta2(1,1:end-1))),'--','color',colour(4,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta2(2,1:end-1))),'--','color',colour(6,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta2(3,1:end-1))),'--','color',colour(5,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta2(4,1:end-1))),'--','color',colour(8,:))
semilogy(Rp/x_e,-180/pi*unwrap(angle(Theta2(5,1:end-1))),'--','color',colour(2,:))
hold off
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
box on; grid on; xlabel('$\rho$ [-]','interpreter','latex'); ylabel('$\angle \tilde{T}_e$ $[^{\circ}]$','interpreter','latex')
axis([0,1,55,360+55])
l2 = legend(Cell1,'location','NorthWest'); set(l2,'interpreter','latex');
annotation(h79,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(b)'},'LineStyle','none','FontSize',14,'interpreter','latex');

tightfig(h79)

%% Spatial derivations
cpp = [4,6,5,8,2];
h81 = figure(81);
hold on; for i = 1:length(F);
plot(Rp/x_e,0.5*omega(i)./(-diff(log(abs(Theta1(i,:))))/dr).^2,'color',colour(cpp(i),:)); end
for i = 1:length(F);
plot(Rp/x_e,0.5*omega(i)./(-diff(log(abs(Theta2(i,:))))/dr).^2,'--','color',colour(cpp(i),:)); end
hold off
set(gca,'yscale','log')
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
box on; grid on; xlabel('$\rho$ [-]','interpreter','latex'); ylabel('$\chi_{A}$ [m$^2$/s]','interpreter','latex')
axis([0,1,1,1e3])
l3 = legend(Cell1,'location','SouthWest'); set(l3,'interpreter','latex');

annotation(h81,'textbox',...
    [0.508571428571429 0.669476189113801 0.112857145122119 0.0809523823147729],...
    'String',{'\chi(\omega)'},...
    'LineStyle','none',...
    'FontSize',14);

annotation(h81,'arrow',[0.295714285714286 0.517142857142857],...
    [0.378047619047619 0.660952380952381]);

annotation(h81,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(a)'},'LineStyle','none','FontSize',14,'interpreter','latex');


tightfig(h81)

h82 = figure(82);
hold on; for i = 1:length(F);
    Phase1 = -unwrap(angle(Theta1(i,:))); chi_phi1 = 0.5*omega(i)./diff(Phase1/dr).^2;
plot(Rp/x_e,chi_phi1,'color',colour(cpp(i),:)); end
for i = 1:length(F);
        Phase2 = -unwrap(angle(Theta2(i,:))); chi_phi2 = 0.5*omega(i)./diff(Phase2/dr).^2;
plot(Rp/x_e,chi_phi2,'--','color',colour(cpp(i),:)); end
hold off
set(gca,'yscale','log')
ht1 = title(sprintf('$$ \\chi_e = %.0f $$ [m$$^2$$/s]',chi),'fontweight','normal'); set(ht1,'interpreter','latex')
box on; grid on; xlabel('$\rho$ [-]','interpreter','latex'); ylabel('$\chi_{\phi}$ [m$^2$/s]','interpreter','latex')
axis([0,1,1,1e3])
l3 = legend(Cell1,'location','SouthWest'); set(l3,'interpreter','latex');

annotation(h82,'textbox',...
    [0.606024884830451 0.643606793224407 0.112857145122119 0.0809523823147729],...
    'String',{'\chi(\omega)'},...
    'LineStyle','none',...
    'FontSize',14);

annotation(h82,'arrow',[0.381428571428571 0.602857142857142],...
    [0.448523809523811 0.731428571428573]);

annotation(h82,'textbox',[0.918 0.140 0.010 0.0853],'String',{'(b)'},'LineStyle','none','FontSize',14,'interpreter','latex');


tightfig(h82)

%% +++++++++++++++++
%
figure(2)
hold on
plot(Rp/x_e,abs(Theta1(5,1:end-1)),'color',colour(2,:))
plot(Rp/x_e,abs(Theta2(5,1:end-1)),'--','color',colour(2,:))
hold off
box on



return

% total power calculation
for i = length(Pdep1):-1:1;  
    Pint(:,i) = dr*trapz(Pdep1(:,1:i).'/MW2keVs).';
end
figure(78)
plot(rpd(1:end-1)/x_e,Pint,'k'); xlabel('\rho');ylabel('P_{tot} [MW/m^2]')
grid on; axis([rpd(1)/x_e,rpd(end)/x_e,0,1.1*max(Pint)])
